@@ -46,7 +46,6 @@
 #include <tdeaccel.h>
 #include <kglobalaccel.h>
 #include <kkeydialog.h>
-#include <tdepopupmenu.h>
 
 // application specific includes
 #include "mixertoolbox.h"
@@ -119,7 +118,7 @@ KMixWindow::initActions()
 	(void) new TDEAction( i18n( "Hardware &Information" ), 0, TQT_TQOBJECT(this), TQT_SLOT( slotHWInfo() ), actionCollection(), "hwinfo" );
 	(void) new TDEAction( i18n( "Hide Mixer Window" ), Key_Escape, TQT_TQOBJECT(this), TQT_SLOT(hide()), actionCollection(), "hide_kmixwindow" );
 
-	m_globalAccel = new TDEGlobalAccel( TQT_TQOBJECT(this) );
+	m_globalAccel = new TDEGlobalAccel(this, "KMix");
 	m_globalAccel->insert( "Increase volume", i18n( "Increase Volume of Master Channel"), TQString(),
 			TDEShortcut(TQString("XF86AudioRaiseVolume")), TDEShortcut(TQString("XF86AudioRaiseVolume")), TQT_TQOBJECT(this), TQT_SLOT( increaseVolume() ) );
 	m_globalAccel->insert( "Decrease volume", i18n( "Decrease Volume of Master Channel"), TQString(),
@@ -194,27 +193,8 @@ KMixWindow::updateDocking()
 
 	if (m_showDockWidget)
 	{
-
 		// create dock widget
-                // !! This should be a View in the future
 		m_dockWidget = new KMixDockWidget( Mixer::mixers().first(), this, "mainDockWidget", m_volumeWidget, m_dockIconMuting );
-
-/* Belongs in KMixDockWidget
-		// create RMB menu
-		TDEPopupMenu *menu = m_dockWidget->contextMenu();
-
-		// !! check this
-		TDEAction *a = actionCollection()->action( "dock_mute" );
-		if ( a ) a->plug( menu );
-*/
-
-		/*
-		 * Mail from 31.1.2005: "make sure your features are at least string complete"
-		 * Preparation for fixing Bug #55078 - scheduled for KDE3.4.1 .
-		 * This text will be plugged into the dock-icon popup menu.
-		 */
-		TQString selectChannel = i18n("Select Channel"); // This text will be used in KDE3.4.1 !!!
-
 		m_dockWidget->show();
 	}
 }
